# Team Member Roster Card

## Identity
- **Name:** {{name}}
- **Role:** {{role}}
- **Level:** {{level}}
- **Status:** Active

## Git Identity
- **user.name:** {{name}}
- **user.email:** {{email}}

## Personality Profile

### Communication Style
{{personality}}

## Tech Preferences

*Evolves based on project experience.*

| Category | Preference | Notes |
|----------|-----------|-------|
| | | |

### Work Affinity Spectrum
| Type | Affinity |
|------|----------|
| Greenfield | ██████░░░░ 6/10 |
| Maintenance | ██████░░░░ 6/10 |
| Operational | ██████░░░░ 6/10 |
| Documentation | ██████░░░░ 6/10 |
